@@ -1,4 +1,5 @@
 import os
+import sys
 import time
 import glob
 import datetime
@@ -18,6 +19,7 @@ logger = logging.getLogger(__name__)
 CLEANUP_INTERVAL_MS = 0.999
 
 
+
 class BatchProcessor:
     def __init__(self, config):
         self.config = config
@@ -207,14 +209,20 @@ class BatchProcessor:
                 self.callables[t] = cb
             return cb, failure
 
+    def _watchdog_hang_detected(self):
+        logger.error("Watchdog triggered exception, restarting batch")
+        sys.exit(99)
+
     def _execute_safely(self, entrypoint, item):
         # logger.info("SAFE EXECUTION STARTED!")
-        # We cap runtime
-        timeout = 30
         failure = None
         result = None
         try:
-            watchdog = fk.utils.Watchdog.Watchdog(timeout)
+            # We cap runtime at TTL if set or DEFAULT_TTL as default
+            timeout = item.get('ttl_seconds')
+            if not timeout or timeout <=0:
+                timeout = self.config.get('batch-default-ttl', 30)
+            watchdog = fk.utils.Watchdog.Watchdog(timeout, self._watchdog_hang_detected)
             # logger.info("££££ Entry")
             unpackable = entrypoint(item, self.config)
             try:
@@ -225,7 +233,7 @@ class BatchProcessor:
                 return None, failure
             # logger.info("££££ Exit")
         except fk.utils.Watchdog.Watchdog:
-            logger.warning("Watchdag triggered exception")
+            logger.warning("Watchdog triggered exception")
             failure = f"Execution timed out after {timeout} seconds"
         except Exception as e:
             logger.warning("")
@@ -344,16 +352,16 @@ class BatchProcessor:
     def update_hang_status(self):
         self.db.update_batch_hang_status()
 
-    def retry_hung_jobs_older_than(self, time_sec=30):
-        self.db.bump_batch_items(self.db.IN_PROGRESS, self.db.PENDING, time_sec)
+    def retry_hung_jobs(self):
+        self.db.bump_batch_items(self.db.HUNG, self.db.PENDING)
 
-    def delete_hung_jobs_older_than(self, time_sec=30):
-        self.db.delete_batch_items_with_status_older_than(self.db.IN_PROGRESS, time_sec)
+    def delete_hung_jobs(self):
+        self.db.delete_batch_items_with_status(self.db.HUNG)
 
     def delete_failed_jobs(self):
-        self.db.delete_batch_items_with_status_older_than(self.db.FAILED, 0)
+        self.db.delete_batch_items_with_status(self.db.FAILED)
 
-    def delete_all_jobs(self, time_sec=30):
+    def delete_all_jobs(self):
         self.db.delete_all()
 
     def bump_job_by_id(self, id, status):
