@@ -6,6 +6,9 @@ class Server:
         self.config = config
         self.batch_processor = BatchProcessor(self.config)
 
+    def verify(self):
+        return self.batch_processor.verify()
+
     # Start server and serve until it is aborted
     def run(self):
         while True:
