@@ -208,14 +208,14 @@ $$ language plpgsql;
                 where status = %(from_status)s
                 and ttl_seconds is not null
                 and ttl_seconds > 0
-                and updated_at < ( now() - (ttl_seconds * interval '1 second'))
+                and extract('epoch' from ( now() - updated_at )) > ttl_seconds
                 ;
                 """,
             {"from_status": (self.IN_PROGRESS,), "to_status": (self.HUNG,)},
         )
 
-    # Update status of all jobs with from_status to to_status given they have time delta longer than given time
-    def bump_batch_items(self, from_status=IN_PROGRESS, to_status=PENDING, time_sec=30):
+    # Update status of all jobs with from_status to to_status
+    def bump_batch_items(self, from_status=IN_PROGRESS, to_status=PENDING):
         return self.dbc.query_none(
             """
                 update batch_log
@@ -223,10 +223,9 @@ $$ language plpgsql;
                     status=%(to_status)s,
                     updated_at=now()
                 where status = %(from_status)s
-                and updated_at < ( now() - (%(time_sec)s * interval '1 second'))
                 ;
                 """,
-            {"from_status": (from_status,), "to_status": (to_status,), "time_sec": (time_sec,)},
+            {"from_status": (from_status,), "to_status": (to_status,)},
         )
 
     # Update status of a batch item in the batch log, making sure to fail if the id and updated_at don't match, providing a guarantee of atomic operation
@@ -322,15 +321,14 @@ $$ language plpgsql;
         )
 
     # Delete batch items with given status and update_at longer than given time
-    def delete_batch_items_with_status_older_than(self, status, updated_at):
+    def delete_batch_items_with_status(self, status):
         self.dbc.query_none(
             """
                 delete from batch_log
-                where status = %(status)s,
-                and updated_at >= %(updated_at)s
+                where status = %(status)s
                 ;
                 """,
-            {"status": (status,), "updated_at": (updated_at,)},
+            {"status": (status,)},
         )
 
     # Clear out the batch items table
